Package 'trekfont'

Title: Star Trek Fonts Collection
Description: Provides a collection of true type and open type Star Trek-themed fonts.
Authors: Matthew Leonawicz [aut, cre] (ORCID: <https://orcid.org/0000-0001-9452-2771>)
Maintainer: Matthew Leonawicz <[email protected]>
License: GPL-3
Version: 0.9.6
Built: 2026-05-31 10:28:14 UTC
Source: https://github.com/leonawicz/trekfont

Help Index


Show the complete font set

Description

List all available Star Trek fonts contained in the package.

Usage

show_trekfonts()

Value

a character vector.

Examples

show_trekfonts()

trekfont: Star Trek Fonts Collection

Description

logo

Provides a collection of true type and open type Star Trek-themed fonts.

Author(s)

Maintainer: Matthew Leonawicz [email protected] (ORCID)

See Also

Useful links:


Available Star Trek fonts.

Description

Comprehensive listing of all available fonts. These fonts are sourced from https://github.com/wrstone/fonts-startrek under the GPL-3 license.

Usage

trekfonts

Format

A character vector of 107 font files.