| Title: | Star Trek Fonts Collection |
|---|---|
| Description: | Provides a collection of true type and open type Star Trek-themed fonts. |
| Authors: | Matthew Leonawicz [aut, cre] (ORCID: <https://orcid.org/0000-0001-9452-2771>) |
| Maintainer: | Matthew Leonawicz <[email protected]> |
| License: | GPL-3 |
| Version: | 0.9.6 |
| Built: | 2026-05-31 10:28:14 UTC |
| Source: | https://github.com/leonawicz/trekfont |
List all available Star Trek fonts contained in the package.
show_trekfonts()show_trekfonts()
a character vector.
show_trekfonts()show_trekfonts()
Provides a collection of true type and open type Star Trek-themed fonts.
Maintainer: Matthew Leonawicz [email protected] (ORCID)
Useful links:
Comprehensive listing of all available fonts. These fonts are sourced from https://github.com/wrstone/fonts-startrek under the GPL-3 license.
trekfontstrekfonts
A character vector of 107 font files.